@@ -38,21 +38,16 @@ extern const char *ais8_001_22_shape_names[8];
 //////////////////////////////////////////////////////////////////////
 
 class Ais8_001_22_SubArea {
-public:
-    //Ais8_001_22_AreaShapeEnum area_shape;
+ public:
     virtual Ais8_001_22_AreaShapeEnum getType() const = 0;
-    // FIX: make the destructor pure virtual
-    virtual ~Ais8_001_22_SubArea() //= 0;
-    { /* std::cout << "Ais8_001_22_Subarea: destructor" << std::endl;*/ };
-    virtual void print()=0;
+    virtual ~Ais8_001_22_SubArea() {}
 };
 
-// TODO: need pad?
 Ais8_001_22_SubArea* ais8_001_22_subarea_factory(const std::bitset<AIS8_MAX_BITS> &bs, const size_t offset);
 
 // or Point if radius is 0
 class Ais8_001_22_Circle : public Ais8_001_22_SubArea {
-public:
+ public:
     float x,y; // longitude and latitude
     // Going to assume that the precision is load of crap
     int precision; // How many decimal places for x and y.  Track it, but it's useless in my opinion
@@ -60,13 +55,12 @@ public:
     unsigned int spare; // 18 bits
 
     Ais8_001_22_Circle(const std::bitset<AIS8_MAX_BITS> &bs, const size_t offset);
-    ~Ais8_001_22_Circle() {/* std::cout << "Ais8_001_22_Circle: destructor" << std::endl; */};
+    ~Ais8_001_22_Circle() {}
     Ais8_001_22_AreaShapeEnum getType() const {return AIS8_001_22_SHAPE_CIRCLE;}
-    void print();
 };
 
 class Ais8_001_22_Rect : public Ais8_001_22_SubArea {
-public:
+ public:
     float x,y; // longitude and latitude
     int precision; // How many decimal places for x and y.  Useless
     int e_dim_m; // East dimension in meters
@@ -75,36 +69,31 @@ public:
     unsigned int spare; // 5 bits
 
     Ais8_001_22_Rect(const std::bitset<AIS8_MAX_BITS> &bs, const size_t offset);
-    ~Ais8_001_22_Rect() { /* std::cout << "Ais8_001_22_Rect: destructor" << std::endl; */};
+    ~Ais8_001_22_Rect() {}
     Ais8_001_22_AreaShapeEnum getType() const {return AIS8_001_22_SHAPE_RECT;}
-    void print();
 
 };
 
 class Ais8_001_22_Sector : public Ais8_001_22_SubArea {
-public:
+ public:
     float x,y; // longitude and latitude
-    int precision; // How many decimal places for x and y  FIX: in IMO, but not RTCM
+    // TODO(schwehr): precision in IMO, but not RTCM.  Double check
+    int precision; // How many decimal places for x and y
     int radius_m;
     int left_bound_deg;
     int right_bound_deg;
-    //int spare; //  bits
 
     Ais8_001_22_Sector(const std::bitset<AIS8_MAX_BITS> &bs, const size_t offset);
-    ~Ais8_001_22_Sector() { /* std::cout << "Ais8_001_22_Sector: destructor" << std::endl; */ };
+    ~Ais8_001_22_Sector() {}
     Ais8_001_22_AreaShapeEnum getType() const {return AIS8_001_22_SHAPE_SECTOR;}
-    void print();
 };
 
 // Or Waypoint
 // Must have a point before on the VDL
-// FIX: do I bring in the prior point x,y, precision?
+// TODO(schwehr): do I bring in the prior point x,y, precision?
 class Ais8_001_22_Polyline : public Ais8_001_22_SubArea {
-public:
-
-    // x, y, and precision sent as separate Point before the waypoint start
-    //float x,y; // longitude and latitude
-    //int precision; // How many decimal places for x and y.  FIX: in IMO
+ public:
+    // TODO(schwehr): int precision; // How many decimal places for x and y.  FIX: in IMO
 
     // Up to 4 points
     std::vector<float> angles;
@@ -112,20 +101,16 @@ public:
     unsigned int spare; // 2 bit
 
     Ais8_001_22_Polyline(const std::bitset<AIS8_MAX_BITS> &bs, const size_t offset);
-    ~Ais8_001_22_Polyline() { /* std::cout << "Ais8_001_22_Polyline: destructor" << std::endl; */};
+    ~Ais8_001_22_Polyline() {}
     Ais8_001_22_AreaShapeEnum getType() const {return AIS8_001_22_SHAPE_POLYLINE;}
-    void print();
 
 };
 
-// FIX: brin in the prior point?  And do we fold the sub area data
+// TODO(schwehr): bring in the prior point?  And do we fold the sub area data
 // into one polygon if there are more than one?
 class Ais8_001_22_Polygon : public Ais8_001_22_SubArea {
-public:
-
-    // x, y, and precision sent as separate Point before the waypoint start
-    //float x,y; // longitude and latitude
-    //int precision; // How many decimal places for x and y.  FIX: in IMO
+ public:
+    // TODO(schwehr): int precision; // How many decimal places for x and y.  FIX: in IMO
 
     // Up to 4 points in a first message, but aggregated if multiple sub areas
     std::vector<float> angles;
@@ -133,21 +118,19 @@ public:
     unsigned int spare; // 2 bit
 
     Ais8_001_22_Polygon(const std::bitset<AIS8_MAX_BITS> &bs, const size_t offset);
-    ~Ais8_001_22_Polygon() { /* std::cout << "Ais8_001_22_Polygon: destructor" << std::endl; */ };
+    ~Ais8_001_22_Polygon() {}
     Ais8_001_22_AreaShapeEnum getType() const {return AIS8_001_22_SHAPE_POLYGON;}
-    void print();
 };
 
 
 class Ais8_001_22_Text : public Ais8_001_22_SubArea {
-public:
+ public:
     std::string text;
-    //unsigned int spare; // 3 bits
+    // TODO(schwehr): spare?
 
     Ais8_001_22_Text(const std::bitset<AIS8_MAX_BITS> &bs, const size_t offset);
-    ~Ais8_001_22_Text() { /* std::cout << "Ais8_001_22_Text: destructor" << std::endl; */ };
+    ~Ais8_001_22_Text() {}
     Ais8_001_22_AreaShapeEnum getType() const {return AIS8_001_22_SHAPE_TEXT;}
-    void print();
 };
 
 
@@ -156,7 +139,7 @@ public:
 //////////////////////////////////////////////////////////////////////
 
 class Ais8_001_22 : public Ais8 {
-public:
+ public:
     // Common block at the front
     int link_id; // 10 bit id to match up text blocks
     int notice_type; // area_type / Notice Description
@@ -170,12 +153,11 @@ public:
 
     std::vector<Ais8_001_22_SubArea *> sub_areas;
 
-  Ais8_001_22(const char *nmea_payload, const size_t pad);
+    Ais8_001_22(const char *nmea_payload, const size_t pad);
     ~Ais8_001_22();
-    void print();
 
     /*
-       FIX: need some sort of higher level accessors and checks
+       TODO(schwehr): need some sort of higher level accessors and checks
        - return interpreted geometry and associated agreegated text
          - What formats to return?  GeoJSON, WKT, etc?
        - validate that the contents of sub_areas is sane
